==> apache-airflow-3.0.0-source.tar.gz: apache-airflow-3.0.0/task-sdk/README.md <==
<!--
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 -->

# Apache Airflow Task SDK

[![PyPI version](https://badge.fury.io/py/apache-airflow-task-sdk.svg)](https://badge.fury.io/py/apache-airflow)
[![License](https://img.shields.io/:license-Apache%202-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0.txt)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/apache-airflow-task-sdk.svg)](https://pypi.org/project/apache-airflow/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/apache-airflow-task-sdk)](https://pypi.org/project/apache-airflow-task-sdk/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Slack Status](https://img.shields.io/badge/slack-join_chat-white.svg?logo=slack&style=social)](https://s.apache.org/airflow-slack)


The Apache Airflow Task SDK includes interfaces for DAG authors and Task execution logic for Python.

## Installation

To install the Task SDK, use pip:

```bash
pip install apache-airflow-task-sdk
```

==> apache-airflow-3.0.6-source.tar.gz: apache-airflow-3.0.6/task-sdk/README.md <==
<!--
 Licensed to the Apache Software Foundation (ASF) under one
 or more contributor license agreements.  See the NOTICE file
 distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
 with the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing,
 software distributed under the License is distributed on an
 "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 -->

# Apache Airflow Task SDK

[![PyPI version](https://badge.fury.io/py/apache-airflow-task-sdk.svg)](https://badge.fury.io/py/apache-airflow-task-sdk)
[![License](https://img.shields.io/:license-Apache%202-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0.txt)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/apache-airflow-task-sdk.svg)](https://pypi.org/project/apache-airflow-task-sdk/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/apache-airflow-task-sdk)](https://pypi.org/project/apache-airflow-task-sdk/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Slack Status](https://img.shields.io/badge/slack-join_chat-white.svg?logo=slack&style=social)](https://s.apache.org/airflow-slack)


The Apache Airflow Task SDK includes interfaces for DAG authors and Task execution logic for Python.

## Installation

To install the Task SDK, use pip:

```bash
pip install apache-airflow-task-sdk
```
